==> imagekitio-1.1.1.tar.gz: imagekitio-1.1.1/imagekitio/upload.py <==
from __future__ import absolute_import

from imagekitio import utils
import time
import requests
from imagekitio.utils import (PY3, to_bytes, to_bytearray, to_string, string_types, unquote, urlencode, Error,
                             HTTPError, urllib2)


class Upload(object):
    def __init__(self, image=None, options=None, globl=None):
        self.image = image
        self.files = {'image': ''}
        self.option = options

        if PY3:
            self.options = dict(get_defaults(), **globl)
            self.options = dict(self.options, **self.option)
        else:
            self.options = dict(get_defaults().items() + globl.items() + self.option.items())

        self.options["timestamp"] = int(time.time())

        if not verify(self.options) or not self.image:
            raise Error("Invalid or missing upload parameters - %d - %s" % (2400, "BAD_REQUEST"))

        self.signature = utils.calculate_signature(self.options)

    def uploader(self):

        url = utils.get_protocol(False) + '//' + utils.get_image_upload_url(self.options["imagekit_id"])

        form_data = {
            'image': self.image,
            'filename': self.options['filename'],
            'useUniqueFilename': self.options['useUniqueFilename'],
            'folder': self.options["folder"],
            'timestamp': self.options["timestamp"],
            'apiKey': self.options["api_key"],
            'signature': self.signature
        }

        # session = requests.Session()
        r = requests.post(url, data=form_data, files=self.files)
        return r


def get_defaults():
    return {"useUniqueFilename": True,
            "folder": "/"}


def verify(globl):
    if globl['imagekit_id'] and globl['api_key'] and globl['api_secret'] and globl['filename'] and globl['timestamp']:
        return True
    else:
        return False

==> imagekitio-1.2.1.tar.gz: imagekitio-1.2.1/imagekitio/upload.py <==
''' This module contains upload apis calls '''

from __future__ import absolute_import

import time
from imagekitio import utils
import requests


class Upload(object):
    ''' Upload class '''
    def __init__(self, image=None, options=None, globl=None):
        self.image = image
        self.files = {'file': ''}
        self.option = options

        if utils.PY3:
            self.options = dict(get_defaults(), **globl)
            self.options = dict(self.options, **self.option)
        else:
            self.options = dict(get_defaults().items() + globl.items() + self.option.items())

        self.options["timestamp"] = int(time.time())

        if not verify(self.options) or not self.image:
            raise utils.Error("Invalid or missing upload parameters - %d - %s" % (2400, "BAD_REQUEST"))

        self.signature = utils.calculate_signature(self.options)


    def uploader(self):
        ''' Image upload submit function '''
        url = utils.get_protocol(False) + '//' + utils.get_image_upload_api(self.options["imagekit_id"])
        form_data = {
            'image': self.image,
            'filename': self.options['filename'],
            'useUniqueFilename': self.options['useUniqueFilename'],
            'folder': self.options["folder"],
            'timestamp': self.options["timestamp"],
            'apiKey': self.options["api_key"],
            'signature': self.signature
        }

        result = requests.post(url, data=form_data, files=self.files)
        return result


    def uploader_url(self):
        '''' Image upload via url submit function '''
        url = utils.get_protocol(False) + '//' + utils.get_image_upload_url_api(self.options["imagekit_id"])    
        form_data = {
            'url': self.image,
            'filename': self.options['filename'],
            'useUniqueFilename': self.options['useUniqueFilename'],
            'folder': self.options["folder"],
            'timestamp': self.options["timestamp"],
            'apiKey': self.options["api_key"],
            'signature': self.signature
        }
        result = requests.post(url, data=form_data)
        return result


def get_defaults():
    ''' return default option values '''
    return {"useUniqueFilename": True,
            "folder": "/"}


def verify(globl):
    ''' Verify global options '''
    if globl['imagekit_id'] and globl['api_key'] and globl['api_secret'] and globl['filename'] and globl['timestamp']:
        return True
    else:
        return False
